/*
 * Copyright (c) 2009 Fabien Arcellier
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * */

/**
 * It contains the parser to analyse the header of Messages
 * It's Thunderbird service. Defined in every version file
 *
 */
gatherTheSenders.headerParser = Components.
  classes["@mozilla.org/messenger/headerparser;1"].
  getService(Components.interfaces.nsIMsgHeaderParser);

/**
 * It contains methods do work with messages dbView of Thunderbird
 * Methods are specified in the js file dedicated to each navigator
 *
 */
gatherTheSenders.dbView = {

  /**
   * Gets message header by using message key
   *
   * @param key int message key
   */
  getMsgHdrForKey: function(key)
  {
    return gDBView.db.GetMsgHdrForKey(key);
  },//end getMsgHdrForKey()

  /**
   * Gets the message key from the message view indice
   *
   * @param indice int message indice in view
   */
  getMsgKeyForIndice: function(indice)
  {
    return gDBView.getKeyAt(indice);
  },//getMsgKeyForIndice()
  
  
  /**
   * Gets the message sender for the message key
   *
   * @param key int message key in database
   */
  getMsgSenderForKey: function(key)
  {
    var msgHdr = this.getMsgHdrForKey(key);
    return gatherTheSenders.headerParser.extractHeaderAddressMailboxes(msgHdr.author);
  },//getMsgSenderForKey()
  
  
  /**
   * Gets total messages in the current message folder
   *
   */
  getTotalMessages: function()
  {
    return gDBView.msgFolder.getTotalMessages(true);
  }
  
};

 /**
 * It contains methods do work with messages dbView of Thunderbird
 * Methods are specified in the js file dedicated to each version
 *
 */
gatherTheSenders.dbView.selection = {

  
  /**
   * Get an array with indices of message selected
   *
   */
  getSelectionIndices: function()
  {
    return gFolderDisplay.selectedIndices;
  },
  
  
  /**
   * Selects mails by using header as criteria
   *
   * @param aHeaders array headers arrays
   */
  selectMessagesForHeaders: function(aHeaders)
  {
    gFolderDisplay.selectMessages(aHeaders);
  }
  
};