/*
 * Copyright (c) 2009 Fabien Arcellier
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * */
 
/**
 * General object to isolate every methods associate to gather the senders
 *
 */
var gatherTheSenders = {


  /**
   * Select every messages where the sender is common with a sender from messages selected by the user
   * 
   */
  selectAllMsgForSameSenders: function ()
  {    
    var aSenderEmails = [];
    var aMsgKeyToSelect = [];
    
    var senderEmail = "";
    var i = 0;
    var indice = 0;
    var msgKey = 0;
    var numMsgSelected = this.dbView.selection.getSelectionIndices().length;
    
    //Traversing the message selected and extract sender mail adress
    for(i = 0; i < numMsgSelected; i++)
    {
      indice = this.dbView.selection.getSelectionIndices()[i];
      msgKey = this.dbView.getMsgKeyForIndice(indice);
      senderEmail = this.dbView.getMsgSenderForKey(msgKey);
      gatherTheSenders.debug.dump( "selectAllMsgFromSameSenders : email selected "+senderEmail );
      if(this.functions.inArray(aSenderEmails, senderEmail) === false) {
        aSenderEmails.push(senderEmail);
      }
      
    }
    
    gatherTheSenders.debug.dump( "selectAllMsgFromSameSenders : Count of messages selected :" + numMsgSelected );
    gatherTheSenders.debug.dump( "selectAllMsgFromSameSenders : emails selected :" + aSenderEmails );
    
    var totalMsg = this.dbView.getTotalMessages();
    gatherTheSenders.debug.dump( "selectAllMsgFromSameSenders : Count of messages in db :" + totalMsg );
    //TODO : There is an error message, when messages are threaded
    for(indice = 0; indice < totalMsg; indice++)
    {
      try 
      {
        msgKey = this.dbView.getMsgKeyForIndice(indice);     
        senderEmail = this.dbView.getMsgSenderForKey(msgKey);
        if(this.functions.inArray( aSenderEmails, senderEmail ) === true)
        {
          aMsgKeyToSelect.push(this.dbView.getMsgHdrForKey(msgKey));
          gatherTheSenders.debug.dump( "selectAllMsgFromSameSenders : index added to the selection :" + indice );
        }
        
      } 
      catch(ex) 
      {
        gatherTheSenders.debug.dump( "selectAllMsgFromSameSenders : Exception during selection process" + ex +
          ", index " + indice + ", email " + senderEmail );
      }
      
    }
    
    this.dbView.selection.selectMessagesForHeaders(aMsgKeyToSelect);
    gatherTheSenders.debug.dump("Msg keys to select :" + aMsgKeyToSelect);
  }//end selectAllMsgFromSameSenders()
};//end gatherTheSenders{}
 
 
 /**
 * It contains methods do work with messages dbView of Thunderbird
 * Methods are specified in the js file dedicated to each version
 *
 */
gatherTheSenders.dbView = {
  
  /**
   * Gets message header by using message key
   *
   * @param key int message key
   */
  getMsgHdrForKey: null,
  
  /**
   * Gets the message key from the message view indice
   *
   */
  getMsgKeyForIndice: null,
  
  /**
   * Gets the message sender for the message key
   *
   */
  getMsgSenderForKey:null,
  
  /**
   * Gets total messages in the current message folder
   *
   */
  getTotalMessages: null
  
};//end gatherTheSenders.dbView{}


gatherTheSenders.dbView.selection = {


  /**
  * Gets an array with indices of message selected
  * Implementation in Thunderbird specific file
  *
  */
  getSelectionIndices: null,
  
  /**
   * Selects mails by using header as criteria
   *
   */
  selectMessagesForHeaders: null
  
};//end gatherTheSenders.dbView.selection



gatherTheSenders.functions = {


  /**
   * Verify if a value exist in an array
   *
   * @return bool return true if the value is in the array
   * @link http://www.ab-d.fr/date/2007-10-14
   */
  inArray: function(array, p_val)
  {
    for(var i = 0, l = array.length; i < l; i++) {
      if(array[i] == p_val) {
        return true;
      }
    }
    return false;
  }//end inArray()
  
};//end gatherTheSenders.functions{}

/**
 * It contains the parser to analyse the header of Messages
 * It's Thunderbird service. Defined in every version file
 *
 */
gatherTheSenders.headerParser = null;

 /**
  * It contains debug methods. If the debug property is modified, 
  * these methods doesn't have any effect in the code.
  *
  */
gatherTheSenders.debug = {
  ///If true, the application is in debug mode
  debug: false,
  
  
  /**
   * Display a message on the console when debug mode is active
   *
   * @param aMessage array Messages to display
   */
  dump: function(aMessage)
  {
    if(this.debug === true)
    {
      var consoleService = Components.classes["@mozilla.org/consoleservice;1"].
        getService(Components.interfaces.nsIConsoleService);
      consoleService.logStringMessage("Gather Senders : " + aMessage);
    }
    
  }//end dump()
  
};//end gatherTheSenders.debug{}